// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `geof` vocabulary
//!
//! This module requires `ns-geof` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|geof|
//! |**Namespace base IRI**|<http://www.opengis.net/def/function/geosparql/>|
//! |**Description**||
//! |**Is defined by**|<http://www.opengis.net/def/function/geosparql/>|
//!

use crate::namespace;

namespace!(
    "http://www.opengis.net/def/function/geosparql/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `boundary`: 
    boundary, "boundary",
    /// `buffer`: 
    buffer, "buffer",
    /// `convexHull`: 
    convexHull, "convexHull",
    /// `difference`: 
    difference, "difference",
    /// `distance`: 
    distance, "distance",
    /// `ehContains`: 
    ehContains, "ehContains",
    /// `ehCoveredBy`: 
    ehCoveredBy, "ehCoveredBy",
    /// `ehCovers`: 
    ehCovers, "ehCovers",
    /// `ehDisjoint`: 
    ehDisjoint, "ehDisjoint",
    /// `ehEquals`: 
    ehEquals, "ehEquals",
    /// `ehInside`: 
    ehInside, "ehInside",
    /// `ehMeet`: 
    ehMeet, "ehMeet",
    /// `ehOverlap`: 
    ehOverlap, "ehOverlap",
    /// `envelope`: 
    envelope, "envelope",
    /// `getSRID`: 
    getSRID, "getSRID",
    /// `intersection`: 
    intersection, "intersection",
    /// `rcc8dc`: 
    rcc8dc, "rcc8dc",
    /// `rcc8ec`: 
    rcc8ec, "rcc8ec",
    /// `rcc8eq`: 
    rcc8eq, "rcc8eq",
    /// `rcc8ntpp`: 
    rcc8ntpp, "rcc8ntpp",
    /// `rcc8ntppi`: 
    rcc8ntppi, "rcc8ntppi",
    /// `rcc8po`: 
    rcc8po, "rcc8po",
    /// `rcc8tpp`: 
    rcc8tpp, "rcc8tpp",
    /// `rcc8tppi`: 
    rcc8tppi, "rcc8tppi",
    /// `relate`: 
    relate, "relate",
    /// `sfContains`: 
    sfContains, "sfContains",
    /// `sfCrosses`: 
    sfCrosses, "sfCrosses",
    /// `sfDisjoint`: 
    sfDisjoint, "sfDisjoint",
    /// `sfEquals`: 
    sfEquals, "sfEquals",
    /// `sfIntersects`: 
    sfIntersects, "sfIntersects",
    /// `sfOverlaps`: 
    sfOverlaps, "sfOverlaps",
    /// `sfTouches`: 
    sfTouches, "sfTouches",
    /// `sfWithin`: 
    sfWithin, "sfWithin",
    /// `symDifference`: 
    symDifference, "symDifference",
    /// `union`: 
    union, "union"
);
